package com.qs.mp.web.controller.api.user;

import com.qs.mp.channel.domain.Channel;
import com.qs.mp.channel.domain.param.*;
import com.qs.mp.channel.service.IChannelService;
import com.qs.mp.common.core.domain.AjaxResult;
import com.qs.mp.common.enums.*;
import com.qs.mp.web.controller.common.BaseApiController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

@Api(tags = "渠道管理API")
@RestController
@RequestMapping("/api/v1/mp/user")
@Component
public class UserChannelController extends BaseApiController {

    @Autowired
    private IChannelService channelService;


    @ApiOperation(value = "更新门店二维码信息", notes = "更新门店二维码信息")
    @PostMapping("site/update/qrCode")
    public AjaxResult siteUpdateQrCode(@Validated @RequestBody ChannelQrCodeParam qrCodeParam){
        if (null == qrCodeParam || null == qrCodeParam.getChannelId()) {
            return error(ErrorCodeEnum.ERROR_CODE_1001);
        }
        Channel channel =  channelService.getById(qrCodeParam.getChannelId());
        channel.setQrCodePic(qrCodeParam.getQrCode());
        try {
            channelService.updateById(channel);
        } catch (Exception e) {
            return AjaxResult.error("门店'" + channel.getName() + "'二维码更新失败");
        }
        return AjaxResult.success("门店'" + channel.getName() + "'二维码更新成功");
    }

    @ApiOperation(value = "查询门店二维码信息", notes = "查询门店二维码信息")
    @PostMapping("query/qrCode")
    public AjaxResult queryQrCode(@Validated @RequestBody UserChannelQrCodeParam qrCodeParam){
        if (null == qrCodeParam || null == qrCodeParam.getChannelId()) {
            return error(ErrorCodeEnum.ERROR_CODE_1001);
        }
        Channel channel = null;
        try {
            channel = channelService.getById(qrCodeParam.getChannelId());
        } catch (Exception e) {
            return AjaxResult.error("二维码查询失败");
        }
        return AjaxResult.success("",channel.getQrCodePic());
    }


}
